@@ -218,7 +218,3 @@ def main():
     with exception_reporting():
         config = parse_command_line(sys.argv)
         run(config)
-
-
-if __name__ == '__main__':
-    main()
